@@ -32,11 +32,11 @@ class Profile:
     """
 
     def __init__(
-        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta"
+        self, file_paths, parser, q_axis_name="qdcd", theta_axis_name="dcdtheta", pixel_max=1000000
     ):
         self.scans = []
         for f in file_paths:
-            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name))
+            self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max))
         self.q_vectors = None
         self.reflected_intensity = None
 
@@ -211,6 +211,7 @@ class Scan:
         q_axis_name="qdcd",
         theta_axis_name="dcdtheta",
         energy=None,
+        pixel_max=1000000,
     ):
         self.file_path = file_path
         self.metadata, self.data = parser(self.file_path)
@@ -237,6 +238,7 @@ class Scan:
         )
         self.R = unp.uarray(np.zeros(self.q.size), np.zeros(self.q.size),)
         self.n_pixels = np.zeros(self.q.size)
+        self.pixel_max = pixel_max
 
     def __str__(self):
         """
@@ -311,7 +313,11 @@ class Scan:
         """
         iterator = _get_iterator(unp.nominal_values(self.q), progress)
         for i in iterator:
-            im = image.Image(self.data["file"][i], self.data, self.metadata)
+            im = image.Image(self.data["file"][i], self.data, self.metadata, pixel_maximum=self.pixel_max)
+            if im.skip:
+                self.R = np.delete(self.R, i)
+                self.q = np.delete(self.q, i)
+                continue
             if crop_kwargs is None:
                 im.crop(crop_function)
             else:
